@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: UTF-8 -*-
 
-#   Copyright (C) 2021  Andrew Bauer
+#   Copyright (C) 2022  Andrew Bauer
 #   Copyright (C) 2014  Enno Rodegerdts
 
 #   This program is free software; you can redistribute it and/or modify
@@ -19,7 +19,8 @@
 
 # Standard library imports
 import os
-import sys
+import sys, site
+from sysconfig import get_path  # new in python 3.2
 import time
 import datetime
 from multiprocessing import cpu_count
