@@ -193,7 +193,7 @@ def parallaxtab():
 	
 	while Hdeg < 5 :
 		#line = " \u0027 "        # DOCKER ONLY
-		line = " ' "        # DOCKER ONLY
+		line = " $'$ "
 		dd = Hdeg
 		while dd < 90:
 			line += r"& \multicolumn{{1}}{{l}}{{\textbf{{{}$^\circ$}}}}".format(dd)
@@ -241,7 +241,7 @@ def venparallax():
 	\multicolumn{7}{c}{\textbf{Parallax of Venus and Mars}}\\
 	'''
 	tab += r"""\hline 
-	$H_{a}$ HP & \textbf{.1'} & \textbf{.2'} & \textbf{.3'} & \textbf{.4'} & \textbf{.5'} & \textbf{.6'} \\
+	$H_{a}$ HP & \textbf{.1$'$} & \textbf{.2$'$} & \textbf{.3$'$} & \textbf{.4$'$} & \textbf{.5$'$} & \textbf{.6$'$} \\
 	\hline
 	"""
 	while Hdeg<90:
@@ -333,4 +333,19 @@ where $A$ is the azimuth angle, $L$ is the latitude, $d$ is the declination and
 \end{itemize}
 
 	\end{multicols} \end{document}'''
-	return lx
\ No newline at end of file
+	return lx
+
+#if sys.version_info[0] != 3:
+#    raise Exception("This runs with Python 3")
+
+#fn = "inc"
+#filename = fn + ".tex"
+#outfile = open(filename, mode="w", encoding="utf8")
+#outfile.write(makelatex())
+#outfile.close()
+#command = 'pdflatex {}'.format(filename)
+#os.system(command)
+#print("finished")
+#os.remove(fn + ".tex")
+#os.remove(fn + ".log")
+#os.remove(fn + ".aux")
\ No newline at end of file
